@@ -39,7 +39,8 @@ FONT_PROPERTIES: Dict[str, Optional[Dict[str, Union[str, int]]]] = {
     'italic': {slant: italic},
     'link': {weight: bold, fg: '#ff02a6'},
     'normal': {},
-    'repeated_tag': {slant: italic, fg: '#ff0048'},
+    'repeated_tag': {slant: italic, fg: '#ff002b'},
+    'repeated_word': {weight: bold},
     'tex_command': {fg: '#12d0f6'},
     'tex_argument': {fg: '#999999'},
     'underlined': {underline: True, spacing3: 1}
@@ -49,5 +50,5 @@ FONT_PROPERTIES: Dict[str, Optional[Dict[str, Union[str, int]]]] = {
 FONT_TAGS: Dict[str, str] = {}
 TAGS_FONT: Dict[str, str] = {}
 for k in FONT_PROPERTIES.keys():
-    FONT_TAGS[k] = f'[PYDETEX_FONT:{k.upper()}]'
+    FONT_TAGS[k] = f'⇱PYDETEX_FONT:{k.upper()}⇲'
     TAGS_FONT[FONT_TAGS[k]] = k
