@@ -13,8 +13,10 @@ __all__ = [
     'Button',
     'check_repeated_words',
     'detect_language',
+    'find_tex_command_char',
     'find_tex_commands',
     'find_tex_commands_noargv',
+    'get_diff_startend_word',
     'get_language_tag',
     'IS_OSX',
     'RESOURCES_PATH',
@@ -38,6 +40,7 @@ import platform
 from iso639 import Lang
 # noinspection PyPackageRequirements
 from iso639.exceptions import InvalidLanguageValue
+
 from nltk.corpus import stopwords as _stopwords
 from nltk.stem import SnowballStemmer
 from nltk.tokenize import RegexpTokenizer
@@ -57,7 +60,6 @@ IS_OSX = platform.system() == 'Darwin'
 # Import Button widget
 if IS_OSX:
     from tkmacosx import Button
-
 else:
     from tkinter import Button
 
@@ -113,6 +115,24 @@ def get_language_tag(s: str) -> str:
         return 'Unknown'
 
 
+def get_diff_startend_word(original: str, new: str) -> Tuple[str, str]:
+    """
+    Return the difference of the word from start and end, for example:
+
+    original XXXwordYY
+    new         word
+    diff = (XXX, YY)
+
+    :param original: Original word
+    :param new: New word
+    :return: Diff word
+    """
+    pos: int = original.find(new)
+    if pos == -1:
+        return '', ''
+    return original[0:pos], original[pos + len(new):len(original)]
+
+
 def check_repeated_words(
         s: str,
         lang: str,
@@ -194,6 +214,10 @@ def check_repeated_words(
             continue
         ignored_words.append(w)
 
+    # Add space to newline
+    newline_format = '      \n'
+    s = s.replace('\n', newline_format)
+
     # Separeate words
     wordswin = []  # Stores the words
     words = s.split(' ')
@@ -228,9 +252,13 @@ def check_repeated_words(
         # Check if the word exist on list
         if w in wordswin and w != '':
             ww = wordswin[::-1].index(w) + 1
-            original_w = f'{font_tag_format}<{tag}:{ww}>' \
-                         f'{font_param_format}{original_w}' \
-                         f'{font_tag_format}</{tag}>{font_normal_format}'
+            stemmed_word = tokenizer.tokenize(original_w)[0]
+            diff_word = get_diff_startend_word(original_w, stemmed_word)
+            if diff_word == ('', ''):
+                stemmed_word = original_w
+            original_w = f'{diff_word[0]}{font_tag_format}<{tag}:{ww}>' \
+                         f'{font_param_format}{stemmed_word}' \
+                         f'{font_tag_format}</{tag}>{font_normal_format}{diff_word[1]}'
 
         # Push the new word
         wordswin.append(w)
@@ -241,7 +269,9 @@ def check_repeated_words(
         new_s.append(original_w)
 
     # Return string with repeated format
-    return ' '.join(new_s)
+    out_s = ' '.join(new_s)
+    out_s = out_s.replace(newline_format, '\n')
+    return out_s
 
 
 def split_tags(s: str, tags: List[str]) -> List[Tuple[str, str]]:
@@ -339,6 +369,47 @@ def validate_float(p: str) -> bool:
     return False
 
 
+def find_tex_command_char(
+        s: str,
+        symbols_char: Union[Tuple[str, str], str],
+        ignore_escape: bool = False
+) -> Tuple[Tuple[int, int], ...]:
+    """
+    Find symbols command positions. Example:
+
+           00000000001111111111....
+           01234567890123456789....
+    Input: This is a $formula$ and this is not.
+    Output: ((10, 18), ...)
+
+    :param s: String
+    :param symbols_char: Symbols to check
+    :param ignore_escape: Ignores \\char
+    :return: Positions
+    """
+    if isinstance(symbols_char, str):
+        symbols_char = (symbols_char, symbols_char)
+    assert len(symbols_char) == 2
+    assert len(symbols_char[0]) == 1 and len(symbols_char[1]) == 1
+
+    s = '_' + s
+    r = False  # Inside tag
+    a = 0
+    found = []
+
+    for i in range(1, len(s)):
+        # Open tag
+        if not r and s[i] == symbols_char[0] and (not ignore_escape or ignore_escape and s[i - 1] != '\\'):
+            a = i
+            r = True
+        # Close
+        elif r and s[i] == symbols_char[1] and (not ignore_escape or ignore_escape and s[i - 1] != '\\'):
+            r = False
+            found.append((a - 1, i - 1))
+
+    return tuple(found)
+
+
 def apply_tag_between_inside(
         s: str,
         symbols_char: Tuple[str, str],
@@ -366,61 +437,118 @@ def apply_tag_between_inside(
 
     assert len(tags) == 4
     a, b, c, d = tags
+    tex_tags = find_tex_command_char(s, symbols_char, ignore_escape)
 
-    s = '_' + s
+    if len(tex_tags) == 0:
+        return s
     new_s = ''
-    r = False  # Inside tag
-    for i in range(1, len(s)):
-        # Open tag
-        if not r and s[i] == symbols_char[0] and (not ignore_escape or ignore_escape and s[i - 1] != '\\'):
-            new_s += a + s[i] + b
-            r = True
-        elif r and s[i] == symbols_char[1] and (not ignore_escape or ignore_escape and s[i - 1] != '\\'):
-            new_s += c + s[i] + d
-            r = False
+    k = 0  # Moves through tags
+
+    for i in range(len(s)):
+        if k < len(tex_tags) and i in tex_tags[k]:
+            if i == tex_tags[k][0]:
+                new_s += a + s[i] + b
+            else:
+                new_s += c + s[i] + d
+                k += 1
         else:
             new_s += s[i]
+
     return new_s
 
 
-def find_tex_commands(s: str, par: Tuple[str, str] = ('{', '}')) -> Tuple[Tuple[int, int, int], ...]:
+def find_tex_commands(s: str) -> Tuple[Tuple[int, int, int, int, bool], ...]:
     """
     Find all tex commands within a code.
 
              00000000001111111111222
              01234567890123456789012
-                     x       x    x
-    Example: This is \aCommand{nice}... => ((8,16,21), ...)
+                     x       x x  x
+    Example: This is \aCommand{nice}... => ((8,16,18,21), ...)
 
     :param s: Latex code
-    :param par: Parenthesis format
     :return: Tuple if found codes
     """
     found = []
     is_cmd = False
     is_argv = False
     s += '_'
-    a, b, c = 0, 0, 0
-    depth = 0
+    a, b, c0, c1, d = 0, -1, 0, 0, 0
+    depth_0 = 0  # {}
+    depth_1 = 0  # []
+    cont_chars = ('{', '[', ' ', '\n')
+    cmd_idx = 0  # index
+
     for i in range(len(s) - 1):
+        # print(i, s[i], depth_0, depth_1, is_cmd, is_argv)
+
+        # Start a command
         if not is_cmd and s[i] == '\\' and s[i + 1] in VALID_TEX_COMMAND_CHARS:
-            a = i
-            is_cmd = True
-        elif is_cmd and not is_argv and s[i] != par[0] and s[i] not in VALID_TEX_COMMAND_CHARS:
+            a, b, is_cmd, is_argv = i, -1, True, False
+            cmd_idx += 1
+
+        # If command before args encounter an invalid chad, disables the command
+        elif is_cmd and not is_argv and s[i] not in cont_chars and s[i] not in VALID_TEX_COMMAND_CHARS:
             is_cmd = False
-        elif is_cmd and not is_argv and s[i] == par[0]:
-            b = i - 1
+            if s[i] == '\\' and s[i + 1] in VALID_TEX_COMMAND_CHARS:
+                a, b, is_cmd, is_argv = i, -1, True, False
+                cmd_idx += 1
+
+        # If command has a new line, but following chars are not space
+        elif is_cmd and not is_argv and s[i] == '\n' and s[i + 1] in VALID_TEX_COMMAND_CHARS:
+            is_cmd = False
+
+        # If command, not arg, but an invalid char follows the space, disables the command
+        elif is_cmd and not is_argv and s[i - 1] == ' ' and s[i] not in cont_chars:
+            is_cmd = False
+
+        # Inits a new arg
+        elif is_cmd and s[i] in ('{', '[') and s[i - 1] != '\\':
             is_argv = True
-            depth = 0
-        elif is_cmd and is_argv and s[i] == par[0] and s[i - 1] != '\\':
-            depth += 1
-        elif is_cmd and is_argv and s[i] == par[1] and s[i - 1] != '\\':
-            if depth == 0:  # Finished
-                c = i - 1
-                found.append((a, b, c))
+            if b == -1:
+                b = i - 1
+                depth_0, depth_1 = 0, 0
+            if s[i] == '{':
+                if depth_0 == 0:
+                    c0 = i + 1
+                depth_0 += 1
+            else:
+                if depth_1 == 0:
+                    c1 = i + 1
+                depth_1 += 1
+
+        # Ends the argument, only if depth condition satisfies
+        elif is_cmd and is_argv and s[i] in ('}', ']') and s[i - 1] != '\\':
+            if s[i] == '}':
+                depth_0 -= 1
+            else:
+                depth_1 -= 1
+            if depth_0 == 0 and depth_1 == 0:  # Finished
+                d = i - 1
+                found.append([a, b, c0 if s[i] == '}' else c1, d, cmd_idx])
+                if s[i + 1] not in cont_chars:
+                    is_cmd = False
+                is_argv = False
+            elif depth_0 < 0 or depth_1 < 0:  # Invalid argument (parenthesis imbalance)
                 is_cmd = False
                 is_argv = False
-            depth -= 1
+
+    # Check if command continues
+    if len(found) == 0:
+        return ()
+    elif len(found) == 1:
+        found[0][4] = False
+    else:
+        for k in range(1, len(found)):
+            if found[k][4] == found[k - 1][4]:
+                found[k - 1][4] = True
+            else:
+                found[k - 1][4] = False
+            if k == len(found) - 1:
+                found[k][4] = False
+    for k in range(len(found)):
+        # noinspection PyUnresolvedReferences
+        found[k] = tuple(found[k])
 
     return tuple(found)
 
@@ -440,33 +568,56 @@ def find_tex_commands_noargv(s: str) -> Tuple[Tuple[int, int], ...]:
     found = []
     is_cmd = False
     s += '_'
-    a, b = 0, 0
+    a = 0
+    cont_chars = ('{', '[', ' ')
+
     for i in range(len(s) - 1):
+
         if not is_cmd and s[i] == '\\' and s[i + 1] in VALID_TEX_COMMAND_CHARS:
+            if i > 0 and s[i - 1] == '⇲':
+                continue
             a = i
             is_cmd = True
+
         elif is_cmd and s[i] == '\\':
-            b = i - 1
-            if b - a > 0:
-                found.append((a, b))
+            if i - 1 - a > 0:
+                found.append([a, i - 1])
             a = i
-        elif is_cmd and s[i] == '{':
+
+        elif is_cmd and s[i] in ('{', '['):
             is_cmd = False
-        elif is_cmd and s[i] not in VALID_TEX_COMMAND_CHARS and s[i] != '{':
-            b = i - 1
+
+        # If command, not arg, but an invalid char follows the space, disables the command
+        elif is_cmd and s[i - 1] == ' ' and s[i] not in cont_chars:
             is_cmd = False
-            found.append((a, b))
+            found.append([a, i - 1])
+
+        elif is_cmd and s[i] not in VALID_TEX_COMMAND_CHARS and s[i] not in cont_chars:
+            is_cmd = False
+            found.append([a, i - 1])
+
+        # print(i, s[i], is_cmd, found)
 
     if is_cmd and a != len(s) - 2:
-        found.append((a, len(s) - 2))
+        found.append([a, len(s) - 2])
+
+    # Strip chars
+    for k in range(len(found)):
+        ch = found[k][1]
+        for j in range(ch):
+            if s[found[k][1]] == ' ':
+                found[k][1] -= 1
+            else:
+                break
+        # noinspection PyUnresolvedReferences
+        found[k] = tuple(found[k])
 
     return tuple(found)
 
 
 def apply_tag_tex_commands(
         s: str,
-        tags: Union[Tuple[str, str, str, str, str], str],
-        par: Tuple[str, str] = ('{', '}')
+        tags: Union[Tuple[str, str, str, str, str], str]
 ) -> str:
     """
     Apply tag to tex command. For example, if tag is [1,2,3,4,5]:
@@ -476,7 +627,6 @@ def apply_tag_tex_commands(
 
     :param s: Code
     :param tags: Tags (length 5)
-    :param par: Parenthesis format
     :return: Code with tags
     """
     if isinstance(tags, str):
@@ -486,7 +636,7 @@ def apply_tag_tex_commands(
     assert len(tags) == 5
     a, b, c, d, e = tags  # Unpack
 
-    tex_tags = find_tex_commands(s, par)
+    tex_tags = find_tex_commands(s)
     if len(tex_tags) == 0:
         return s
     new_s = ''
@@ -496,15 +646,21 @@ def apply_tag_tex_commands(
         i += 1
         if i == len(s):
             break
-        if k < len(tex_tags) and i in tex_tags[k]:
+        if k < len(tex_tags) and i in tex_tags[k][0:4]:
             if i == tex_tags[k][0]:
                 new_s += a + s[i]
             elif i == tex_tags[k][1]:
-                new_s += s[i] + b + s[i + 1] + c
-                i += 1
-            elif i == tex_tags[k][2]:
+                new_s += s[i] + b
+            elif i == tex_tags[k][2] and i != tex_tags[k][3]:
+                new_s += c + s[i]
+            elif i == tex_tags[k][3]:
+                if i == tex_tags[k][2]:
+                    new_s += c
                 new_s += s[i] + d + s[i + 1] + e
                 i += 1
+                # if continues
+                if tex_tags[k][4]:
+                    new_s += b
                 k += 1
         else:
             new_s += s[i]
@@ -575,16 +731,11 @@ def syntax_highlight(s: str) -> str:
     # Format commands with {arguments}
     s = apply_tag_tex_commands(
         s=s,
-        tags=(_FONT_TAGS['tex_command'], _FONT_TAGS['normal'], _FONT_TAGS['tex_argument'], _FONT_TAGS['normal'],
-              _FONT_TAGS['normal'])
-    )
-
-    # Format commands with [arguments]
-    s = apply_tag_tex_commands(
-        s=s,
-        tags=(_FONT_TAGS['tex_command'], _FONT_TAGS['normal'], _FONT_TAGS['tex_argument'], _FONT_TAGS['normal'],
-              _FONT_TAGS['normal']),
-        par=('[', ']')
+        tags=(_FONT_TAGS['tex_command'],
+              _FONT_TAGS['normal'],
+              _FONT_TAGS['tex_argument'],
+              _FONT_TAGS['normal'],
+              '')
     )
 
     # Format commands without arguments
